@@ -40,20 +40,23 @@ predictFailureModel = function(model, newdata) {
   n = nrow(newdata)
   if (type == "classif") {
     levs = model$task.desc$class.levels
-    res = if (ptype == "response")
+    res = if (ptype == "response") {
       factor(rep(NA_character_, n), levels = levs)
-    else
+    } else {
       matrix(NA_real_, nrow = n, ncol = length(levs), dimnames = list(NULL, levs))
+    }
   } else if (type == "regr") {
-    res = if (ptype == "response")
+    res = if (ptype == "response") {
       rep(NA_real_, n)
-    else
+    } else {
       matrix(NA_real_, nrow = n, ncol = 2L, dimnames = list(NULL, c("response", "se")))
+    }
   } else if (type == "surv") {
-    if (ptype == "response")
+    if (ptype == "response") {
       res = rep.int(NA_real_, n)
-    else
+    } else {
       stop("Predict type 'prob' for survival not yet supported")
+    }
   } else if (type == "costsens") {
     levs = model$task.desc$class.levels
     res = factor(rep(NA_character_, n), levels = levs)
