@@ -31,7 +31,9 @@ makeRLearner.regr.h2o.glm = function() {
 trainLearner.regr.h2o.glm = function(.learner, .task, .subset, .weights = NULL, ...) {
 
   # check if h2o connection already exists, otherwise start one
-  conn.up = tryCatch(h2o::h2o.getConnection(), error = function(err) return(FALSE))
+  conn.up = tryCatch(h2o::h2o.getConnection(), error = function(err) {
+    return(FALSE)
+  })
   if (!inherits(conn.up, "H2OConnection")) {
     h2o::h2o.init()
   }
