@@ -20,7 +20,7 @@ makeRLearner.regr.xgboost = function() {
       makeNumericLearnerParam(id = "lambda", default = 1, lower = 0),
       makeNumericLearnerParam(id = "lambda_bias", default = 0, lower = 0),
       makeNumericLearnerParam(id = "alpha", default = 0, lower = 0),
-      makeUntypedLearnerParam(id = "objective", default = "reg:linear", tunable = FALSE),
+      makeUntypedLearnerParam(id = "objective", default = "reg:squarederror", tunable = FALSE),
       makeUntypedLearnerParam(id = "eval_metric", default = "rmse", tunable = FALSE),
       makeNumericLearnerParam(id = "base_score", default = 0.5, tunable = FALSE),
       makeNumericLearnerParam(id = "max_delta_step", lower = 0, default = 0),
@@ -46,7 +46,7 @@ makeRLearner.regr.xgboost = function() {
       makeUntypedLearnerParam(id = "updater"), # Default depends on the selected booster
       makeNumericLearnerParam(id = "sketch_eps", default = 0.03, lower = 0, upper = 1),
       makeLogicalLearnerParam(id = "one_drop", default = FALSE, requires = quote(booster == "dart")),
-      makeDiscreteLearnerParam(id = "tree_method", default = "exact", values = c("exact", "hist"), requires = quote(booster != "gblinear")),
+      makeDiscreteLearnerParam(id = "tree_method", default = "auto", values = c("auto", "exact", "approx", "hist", "gpu_hist"), requires = quote(booster != "gblinear")),
       makeDiscreteLearnerParam(id = "grow_policy", default = "depthwise", values = c("depthwise", "lossguide"), requires = quote(tree_method == "hist")),
       makeIntegerLearnerParam(id = "max_leaves", default = 0L, lower = 0L, requires = quote(grow_policy == "lossguide")),
       makeIntegerLearnerParam(id = "max_bin", default = 256L, lower = 2L, requires = quote(tree_method == "hist")),
@@ -67,7 +67,7 @@ trainLearner.regr.xgboost = function(.learner, .task, .subset, .weights = NULL,
   parlist = list(...)
 
   if (is.null(parlist$objective)) {
-    parlist$objective = "reg:linear"
+    parlist$objective = "reg:squarederror"
   }
 
   task.data = getTaskData(.task, .subset, target.extra = TRUE)
