@@ -5,7 +5,8 @@ checkMeasures = function(measures, obj, aggr = NULL) {
     measures = ensureVector(measures, n = 1L, cl = "Measure")
     assertList(measures, types = "Measure", min.len = 1L)
   }
-  if (!is.null(aggr))
+  if (!is.null(aggr)) {
     measures = lapply(measures, setAggregation, aggr = aggr)
+  }
   return(measures)
 }
