@@ -49,8 +49,9 @@
 #'
 #' @references Vuk, Miha, and Curk, Tomaz. \dQuote{ROC Curve, Lift Chart, and Calibration Plot.} Metodoloski zvezki. Vol. 3. No. 1 (2006): 89-108.
 #' @export
-generateCalibrationData = function(obj, breaks = "Sturges", groups = NULL, task.id = NULL)
+generateCalibrationData = function(obj, breaks = "Sturges", groups = NULL, task.id = NULL) {
   UseMethod("generateCalibrationData")
+}
 #' @export
 generateCalibrationData.Prediction = function(obj, breaks = "Sturges", groups = NULL, task.id = NULL) {
   checkPrediction(obj, task.type = "classif", predict.type = "prob")
@@ -154,6 +155,8 @@ generateCalibrationData.list = function(obj, breaks = "Sturges", groups = NULL,
 #' @template ret_gg2
 #' @export
 #' @examples
+#' \dontshow{ if (requireNamespace("rpart")) \{ }
+#' \dontshow{ if (requireNamespace("Hmisc")) \{ }
 #' \dontrun{
 #' lrns = list(makeLearner("classif.rpart", predict.type = "prob"),
 #'   makeLearner("classif.nnet", predict.type = "prob"))
@@ -169,6 +172,8 @@ generateCalibrationData.list = function(obj, breaks = "Sturges", groups = NULL,
 #' out = generateCalibrationData(pred)
 #' plotCalibration(out)
 #' }
+#' \dontshow{ \} }
+#' \dontshow{ \} }
 plotCalibration = function(obj, smooth = FALSE, reference = TRUE, rag = TRUE, facet.wrap.nrow = NULL, facet.wrap.ncol = NULL) {
 
   assertClass(obj, "CalibrationData")
